@@ -154,20 +154,20 @@ class State(ConfigBase):
             os.makedirs('/var/db/hp/')
             cmd = 'chmod 755 /var/db/hp/'
             os_utils.execute(cmd)
-        ConfigBase.__init__(self, '/var/db/hp/hplip.state')
+        ConfigBase.__init__(self, '/var/db/hplip.state')
 
 
 class UserConfig(ConfigBase):
     def __init__(self):
+
+        prop.user_dir = os.path.expanduser('~/.hplip')
+        try:
+            if not os.path.exists(prop.user_dir):
+                os.makedirs(prop.user_dir)
+        except OSError:
+            log.error("Failed to create %s directory. User preferences and collection of debug logs can't be supported."%(prop.user_dir))
+
         if not os.geteuid() == 0:
-            prop.user_dir = os.path.expanduser('~/.hplip')
-
-            try:
-                if not os.path.exists(prop.user_dir):
-                    os.makedirs(prop.user_dir)
-            except OSError:
-                pass # This is sometimes OK, if running hpfax: for example
-
             prop.user_config_file = os.path.join(prop.user_dir, 'hplip.conf')
 
             if not os.path.exists(prop.user_config_file):
@@ -182,7 +182,6 @@ class UserConfig(ConfigBase):
 
         else:
             # If running as root, conf file is None
-            prop.user_dir = None
             prop.user_config_file = None
             ConfigBase.__init__(self, None)
 
@@ -293,6 +292,7 @@ def cleanup_spinner():
         sys.stdout.flush()
 
 
+
 # Internal/messaging errors
 
 ERROR_STRINGS = {
