@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/local/bin/python2.7
 # -*- coding: utf-8 -*-
 #
 # magic.py
@@ -251,10 +251,10 @@ magic = [
     [0L, 'string', '=', '#! /bin/python', 'application/x-python'],
     [0L, 'string', '=', '#! /bin/python', 'application/x-python'],
     [0L, 'string', '=', 'eval "exec /bin/python', 'application/x-python'],
-    [0L, 'string', '=', '#!/usr/bin/python', 'application/x-python'],
-    [0L, 'string', '=', '#! /usr/bin/python', 'application/x-python'],
-    [0L, 'string', '=', '#! /usr/bin/python', 'application/x-python'],
-    [0L, 'string', '=', 'eval "exec /usr/bin/python', 'application/x-python'],
+    [0L, 'string', '=', '#!/usr/local/bin/python2.7', 'application/x-python'],
+    [0L, 'string', '=', '#! /usr/local/bin/python2.7', 'application/x-python'],
+    [0L, 'string', '=', '#! /usr/local/bin/python2.7', 'application/x-python'],
+    [0L, 'string', '=', 'eval "exec /usr/local/bin/python2.7', 'application/x-python'],
     [0L, 'string', '=', '#!/usr/local/bin/python2.7', 'application/x-python'],
     [0L, 'string', '=', '#! /usr/local/bin/python2.7', 'application/x-python'],
     [0L, 'string', '=', 'eval "exec /usr/local/bin/python2.7', 'application/x-python'],
