@@ -108,6 +108,7 @@ TECH_CLASSES = [
     "Python11",
     "Saipan",
     "PyramidPlus",
+    "Hbpl1",
     "Kapan",
     "MimasTDR",
 ]
@@ -166,6 +167,7 @@ TECH_CLASS_PDLS = {
     "Copperhead"   : 'pcl3',
     "Copperhead12"   : 'pcl3',
     "Ampere"	   : 'pcl3',
+    "Hbpl1"         : 'hbpl1',
     "Kapan"         : 'pcl3',
     "MimasTDR"      : 'pcl3'
 }
