@@ -463,7 +463,7 @@ def sort_dict_by_value(d):
 
 
 def commafy(val):
-    return unicode(locale.format("%d", val, grouping=True))
+    return locale.format("%d", val, grouping=True).decode(locale.getpreferredencoding())
 
 
 def format_bytes(s, show_bytes=False):
@@ -498,8 +498,13 @@ except AttributeError:
 
 
 def which(command, return_full_path=False):
-    path = os.getenv('PATH').split(':')
+    path=[]
+    path_val = os.getenv('PATH')
+    if path_val:
+        path = path_val.split(':')
 
+    path.append('/usr/bin')
+    path.append('/usr/local/bin')
     # Add these paths for Fedora
     path.append('/sbin')
     path.append('/usr/sbin')
@@ -708,6 +713,7 @@ def checkPyQtImport(): # qt3
     # PyQt
     try:
         import qt
+        import ui
     except ImportError:
         if os.getenv('DISPLAY') and os.getenv('STARTED_FROM_MENU'):
             no_qt_message_gtk()
@@ -757,7 +763,9 @@ def checkPyQtImport(): # qt3
 def checkPyQtImport4():
     try:
         import PyQt4
+        import ui4
     except ImportError:
+        log.error("HPLIP is not installed properly or is installed without graphical support. Please reinstall HPLIP")
         return False
     else:
         return True
@@ -1933,39 +1941,42 @@ def downLoad_status(count, blockSize, totalSize):
 def download_from_network(weburl, outputFile = None, useURLLIB=False):
     result =False
 
-    if weburl is "" or weburl is None:
-        log.error("URL is empty")
+    if platform.system() == "Linux":
+        if weburl is "" or weburl is None:
+            log.error("URL is empty")
+            return result, ""
+
+        if outputFile is None:
+            fp, outputFile = make_temp_file()
+
+        try:
+            if useURLLIB is False:
+                wget = which("wget")
+                if wget:
+                    wget = os.path.join(wget, "wget")
+                    status, output = run("%s --cache=off --tries=3 --timeout=60 --output-document=%s %s" %(wget, outputFile, weburl))
+                    if status:
+                        log.error("Failed to connect to HPLIP site. Error code = %d" %status)
+                        return False, ""
+                else:
+                    useURLLIB = True
+
+            if useURLLIB:
+                sys.stdout.write("Download in progress...")
+                urllib.urlretrieve(weburl, outputFile, downLoad_status)
+
+        except IOError, e:
+            log.error("I/O Error: %s" % e.strerror)
+            return False, ""
+
+        if not os.path.exists(outputFile):
+            log.error("Failed to download %s file."%outputFile)
+            return False, ""
+
+        return True, outputFile
+    else:
         return result, ""
 
-    if outputFile is None:
-        fp, outputFile = make_temp_file()
-
-    try:
-        if useURLLIB is False:
-            wget = which("wget")
-            if wget:
-                wget = os.path.join(wget, "wget")
-                status, output = run("%s --cache=off --tries=3 --timeout=60 --output-document=%s %s" %(wget, outputFile, weburl))
-                if status:
-                    log.error("Failed to connect to HPLIP site. Error code = %d" %status)
-                    return False, ""
-            else:
-                useURLLIB = True
-
-        if useURLLIB:
-            sys.stdout.write("Download in progress...")
-            urllib.urlretrieve(weburl, outputFile, downLoad_status)
-
-    except IOError, e:
-        log.error("I/O Error: %s" % e.strerror)
-        return False, ""
-
-    if not os.path.exists(outputFile):
-        log.error("Failed to get hplip version/ %s file not found."%hplip_version_file)
-        return False, ""
-
-    return True, outputFile
-
 
 
 
