@@ -23,7 +23,7 @@
 __version__ = '1.1'
 __title__ = 'HP device setup using USB'
 __mod__ = 'hp-config_usb_printer'
-__doc__ = "Detects HP printers connected using USB and installs HPLIP printers and faxes in the CUPS spooler. Tries to automatically determine the correct PPD file to use."
+__doc__ = "Udev invokes this tool. Tool configures the USB connected devices (if not configured), detects the plugin, queues issues and notifies to logged-in user."
 
 # Std Lib
 import sys
@@ -35,7 +35,7 @@ import time
 
 # Local
 from base.g import *
-from base import device,utils, tui, models,module, services
+from base import device,utils, tui, models,module, services, os_utils
 from prnt import cups
 from installer import pluginhandler
 
@@ -48,40 +48,44 @@ DBUS_AVIALABLE=False
 
 ##### METHODS #####
 
-# Returns already existing print queues for this printer.
-def get_already_added_queues(udev_MDL, udev_serial_no, udev_back_end,remove_non_hp_config):
-    status, output = utils.run('lpstat -v')
+# remove queues using cups API
+def remove_queues(arg_queues_list):
+    for queue_name in arg_queues_list:
+        cups.delPrinter(queue_name)
 
-    same_printer_queues = []
+
+#Function:  get_queues
+#       Returns the HP, Non HP configured queuese list for a given device serial No and backend
+def get_queues(arg_serial_no, arg_back_end):
+    status, output = utils.run('lpstat -v')
+    hp_conf_queues = []
+    non_hp_conf_queues = []
     for p in output.splitlines():
         try:
             match = LPSTAT_PAT.search(p)
             printer_name = match.group(1)
             device_uri = match.group(2)
-            if device_uri.startswith("cups-pdf:/"):
-                  continue
-            if not USB_PATTERN.search(device_uri):
-                  continue
+            if device_uri.startswith("cups-pdf:/") or not USB_PATTERN.search(device_uri):
+                continue
 
             back_end = BACK_END_PATTERN.search(device_uri).group(1)
             serial = USB_PATTERN.search(device_uri).group(1)
             if USB_SERIAL_INTERFACE.search(serial):
                 serial = USB_SERIAL_INTERFACE.search(serial).group(1)
 
-            log.debug("udev_serial_no[%s] serial[%s] udev_back_end[%s] back_end[%s]"%(udev_serial_no, serial, udev_back_end, back_end))
-            if udev_serial_no == serial and (udev_back_end == back_end or back_end == 'usb'):
-                if remove_non_hp_config and printer_name.find('_') == -1 and printer_name.find('-') != -1:
-                    log.debug("Removed %s Queue"%printer_name)
-                    # remove queues using cups API
-                    cups.delPrinter(printer_name)
+            log.debug("arg_serial_no[%s] serial[%s] arg_back_end[%s] back_end[%s]"%(arg_serial_no, serial, arg_back_end, back_end))
+            if arg_serial_no == serial and (arg_back_end == back_end or back_end == 'usb'):
+                if printer_name.find('_') == -1 and printer_name.find('-') != -1:
+                    non_hp_conf_queues.append(printer_name)
                 else:
-                    same_printer_queues.append(printer_name)
+                    hp_conf_queues.append(printer_name)
 
         except AttributeError:
             pass
 
-    log.debug(same_printer_queues)
-    return same_printer_queues
+    log.debug( "serial No [%s] HP Configured Queues [%s] Non HP Configured Queues [%s]"%(arg_serial_no, hp_conf_queues,non_hp_conf_queues))
+    return hp_conf_queues, non_hp_conf_queues
+
 
 def check_cups_process():
     cups_running_sts = False
@@ -158,7 +162,7 @@ USAGE = [ (__doc__, "", "name", True),
 mod = module.Module(__mod__, __title__, __version__, __doc__, USAGE, (INTERACTIVE_MODE,), None, run_as_root_ok=True, quiet=True)
 opts, device_uri, printer_name, mode, ui_toolkit, loc = mod.parseStdOpts('gh',['time-out=', 'timeout='],handle_device_printer=False)
 
-LOG_FILE = "/var/log/hp/hplip_config_usb_printer.log"
+LOG_FILE = "%s/hplip_config_usb_printer.log"%prop.user_dir
 if os.path.exists(LOG_FILE):
     try:
         os.remove(LOG_FILE)
@@ -167,15 +171,6 @@ if os.path.exists(LOG_FILE):
 
 log.set_logfile(LOG_FILE)
 log.set_where(log.LOG_TO_CONSOLE_AND_FILE)
-cmd="chmod 664 "+LOG_FILE
-sts,output = utils.run(cmd)
-if sts != 0:
-    log.debug("Failed to change log file permissions: %s" %output)
-
-cmd="chgrp lp "+LOG_FILE
-sts,output = utils.run(cmd)
-if sts != 0:
-    log.debug("Failed to change log file group permissions: %s" %output)
 
 try:
     import dbus
@@ -224,16 +219,17 @@ try:
     # ******************************* RUNNING HP-SETUP, IF QUEUE IS NOT ADDED
     time.sleep(1)
     norm_model = models.normalizeModelName(model).lower()
-    remove_non_hp_config =True
     if not mq.get('fax-type', FAX_TYPE_NONE) in (FAX_TYPE_NONE, FAX_TYPE_NOT_SUPPORTED):
-        fax_config_list = get_already_added_queues(norm_model, serial, 'hpfax',remove_non_hp_config)
+        fax_queues_list, fax_config_list_non_hp_conf = get_queues(serial, 'hpfax')
+        remove_queues(fax_config_list_non_hp_conf)
 
-    printer_config_list = get_already_added_queues(norm_model, serial, back_end, remove_non_hp_config)
-    if len(printer_config_list) ==0:
+    print_queues_list, print_queues_list_non_hp_conf = get_queues(serial, back_end)
+    remove_queues(print_queues_list_non_hp_conf)     # Removing Queues which are not configured by HPLIP
+    if len(print_queues_list) ==0:
         if "SMART_INSTALL_ENABLED" not in device_uri:
             cmd ="hp-setup -i -x -a -q %s"%param
             log.debug("%s"%cmd)
-            utils.run(cmd)
+            os_utils.execute(cmd)
 
         if start_systray():
             if "SMART_INSTALL_ENABLED" in device_uri:
@@ -260,22 +256,24 @@ try:
        # ******************************* RUNNING FIRMWARE DOWNLOAD TO DEVICE FOR SUPPORTED PRINTER'S
        fw_download_req = mq.get('fw-download', False)
        if fw_download_req:
-           fw_cmd = utils.which('hp-firmware', True)
-           if fw_cmd:
-                fw_cmd += " -y3 -s %s"%param
-                log.debug(fw_cmd)
-                fw_sts, fw_out = utils.run(fw_cmd)
-                if fw_sts == 0:
-                    log.debug("Firmware downloaded to %s "%device_uri)
-                else:
-                    log.debug("Failed to download firmware to %s device"%device_uri)     
+           fw_cmd = "hp-firmware -y3 -s %s"%param
+           log.info(fw_cmd)
+           fw_sts, fw_out = utils.run(fw_cmd)
+           if fw_sts == 0:
+               log.debug("Firmware downloaded to %s "%device_uri)
+           else:
+               log.warn("Failed to download firmware to %s device"%device_uri)     
 
     # ******************************* REMOVING CUPS CREATED QUEUE, If any
     i =0
     while i <12:
         time.sleep(2)
-        get_already_added_queues(norm_model, serial, 'hpfax',remove_non_hp_config)
-        get_already_added_queues(norm_model, serial, 'hp',remove_non_hp_config)
+        fax_queues_list, fax_queues_list_non_hp_conf = get_queues(serial, 'hpfax')
+        remove_queues(fax_queues_list_non_hp_conf)     # Removing Queues which are not configured by HPLIP
+
+        print_queues_list, print_queues_list_non_hp_conf = get_queues(serial, 'hp')
+        remove_queues(print_queues_list_non_hp_conf)     # Removing Queues which are not configured by HPLIP
+
         if i == 0:
             send_message( device_uri, printer_name, EVENT_DIAGNOSE_PRINTQUEUE, username, job_id,"")
         i += 1
