@@ -52,6 +52,11 @@ def plugin_download_callback(c, s, t):
              utils.format_bytes(c*s))
 
 
+def clean_exit(code = 0):
+    cups.releaseCupsInstance()
+    sys.exit(code)
+
+
 nickname_pat = re.compile(r'''\*NickName:\s*\"(.*)"''', re.MULTILINE)
 
 USAGE = [ (__doc__, "", "name", True),
@@ -68,7 +73,7 @@ USAGE = [ (__doc__, "", "name", True),
           ("To specify a CUPS fax queue name:", "-f<fax> or --fax=<fax> (-i mode only)", "option", False),
           ("Type of queue(s) to install:", "-t<typelist> or --type=<typelist>. <typelist>: print*, fax\* (\*default) (-i mode only)", "option", False),
           ("To specify the device URI to install:", "-d<device> or --device=<device> (--qt4 mode only)", "option", False),
-          ("Remove printers or faxes instead of setting-up:", "-r or --rm or --remove (-u only)", "option", False),
+          ("Remove printers or faxes instead of setting-up:", "-r or --rm or --remove", "option", False),
           utils.USAGE_LANGUAGE,
           utils.USAGE_LOGGING1, utils.USAGE_LOGGING2, utils.USAGE_LOGGING3,
           utils.USAGE_HELP,
@@ -107,15 +112,6 @@ USAGE = [ (__doc__, "", "name", True),
         ]
 
 
-def showPasswordUI(prompt):
-    import getpass
-    print ""
-    print log.bold(prompt)
-    username = raw_input("Username: ")
-    password = getpass.getpass("Password: ")
-
-    return (username, password)
-
 mod = module.Module(__mod__, __title__, __version__, __doc__, USAGE,
                     (INTERACTIVE_MODE, GUI_MODE),
                     (UI_TOOLKIT_QT3, UI_TOOLKIT_QT4),
@@ -211,11 +207,11 @@ if mode == GUI_MODE:
     if ui_toolkit == 'qt3':
         if not utils.canEnterGUIMode():
             log.error("%s requires GUI support (try running with --qt4). Also, try using interactive (-i) mode." % __mod__)
-            sys.exit(1)
+            clean_exit(1)
     else:
         if not utils.canEnterGUIMode4():
             log.error("%s requires GUI support (try running with --qt3). Also, try using interactive (-i) mode." % __mod__)
-            sys.exit(1)
+            clean_exit(1)
 
 if mode == GUI_MODE:
     if ui_toolkit == 'qt3':
@@ -224,7 +220,7 @@ if mode == GUI_MODE:
             from ui import setupform
         except ImportError:
             log.error("Unable to load Qt3 support. Is it installed?")
-            sys.exit(1)
+            clean_exit(1)
 
         if remove:
             log.warn("-r/--rm/--remove not supported in qt3 mode.")
@@ -274,12 +270,13 @@ if mode == GUI_MODE:
             w = setupform.SetupForm(bus, param, jd_port)
         except Error:
             log.error("Unable to connect to HPLIP I/O. Please (re)start HPLIP and try again.")
-            sys.exit(1)
+            clean_exit(1)
 
         app.setMainWidget(w)
         w.show()
 
         app.exec_loop()
+        cups.releaseCupsInstance()
 
     else: # qt4
         try:
@@ -287,7 +284,7 @@ if mode == GUI_MODE:
             from ui4.setupdialog import SetupDialog
         except ImportError:
             log.error("Unable to load Qt4 support. Is it installed?")
-            sys.exit(1)
+            clean_exit(1)
 
         app = QApplication(sys.argv)
         log.debug("Sys.argv=%s printer_name=%s param=%s jd_port=%s device_uri=%s remove=%s" % (sys.argv, printer_name, param, jd_port, device_uri, remove))
@@ -297,17 +294,33 @@ if mode == GUI_MODE:
             log.debug("Starting GUI loop...")
             app.exec_()
         except KeyboardInterrupt:
-            sys.exit(0)
+            clean_exit(0)
 
 
 else: # INTERACTIVE_MODE
     try:
+        try:
+            from base import password
+        except ImportError:
+            log.warn("Failed to import Password Object")
+        else:
+            cups.setPasswordCallback(password.showPasswordPrompt)
 
-        cups.setPasswordCallback(showPasswordUI)
-
+        #Removing Queue
         if remove:
-            log.error("-r/--rm/--remove not supported in -i mode.")
-            sys.exit(1)
+            tui.header("REMOVING PRINT/FAX QUEUE")
+            remove_device = mod.getPrinterName(selected_device_name,None,['hp','hpfax'])
+            selected_device_name = remove_device[0]
+            log.info (log.bold("Removing '%s : %s' Queue"%(remove_device[0],remove_device[1])))
+
+            status, status_str = cups.cups_operation(cups.delPrinter, INTERACTIVE_MODE, '', None, selected_device_name)
+
+            if cups.IPP_OK == status:
+                log.info("Successfully deleted %s Print/Fax queue"%selected_device_name)
+                clean_exit(0)
+            else:
+                log.error("Failed to delete %s Print/Fax queue. Error : %s"%(selected_device_name,status_str))
+                clean_exit(1)
 
         if not auto:
             log.info("(Note: Defaults for each question are maked with a '*'. Press <enter> to accept the default.)")
@@ -322,7 +335,7 @@ else: # INTERACTIVE_MODE
             bus = tui.connection_table()
 
             if bus is None:
-                sys.exit(0)
+                clean_exit(0)
 
             log.info("\nUsing connection type: %s" % bus[0])
 
@@ -351,7 +364,7 @@ else: # INTERACTIVE_MODE
 
         if not mq or mq.get('support-type', SUPPORT_TYPE_NONE) == SUPPORT_TYPE_NONE:
             log.error("Unsupported printer model.")
-            sys.exit(1)
+            clean_exit(1)
 
         if mq.get('fax-type', FAX_TYPE_NONE) in (FAX_TYPE_NONE, FAX_TYPE_NOT_SUPPORTED) and setup_fax:
             #log.warning("Cannot setup fax - device does not have fax feature.")
@@ -362,18 +375,30 @@ else: # INTERACTIVE_MODE
         norm_model = models.normalizeModelName(model).lower()
         plugin = mq.get('plugin', PLUGIN_NONE)
 
-        plugin_installed = utils.to_bool(sys_state.get('plugin', 'installed', '0'))
-        if ignore_plugin_check is False and plugin > PLUGIN_NONE and not plugin_installed:
-            tui.header("PLUG-IN INSTALLATION")
-
-            hp_plugin = utils.which('hp-plugin')
-
-            if hp_plugin:
-                if prop.gui_build:
-                    cmd = "hp-plugin -i"
+        if ignore_plugin_check is False and plugin > PLUGIN_NONE:
+            from installer import pluginhandler
+            pluginObj = pluginhandler.PluginHandle() 
+            plugin_sts = pluginObj.getStatus()
+            if plugin_sts != pluginhandler.PLUGIN_INSTALLED:
+                if plugin_sts == pluginhandler.PLUGIN_VERSION_MISMATCH:
+                    tui.header("UPDATING PLUGIN")
                 else:
-                    cmd = "hp-plugin"
-                os_utils.execute(cmd)
+                    tui.header("PLUG-IN INSTALLATION")
+
+                hp_plugin = utils.which('hp-plugin')
+                if hp_plugin:
+                    cmd = "hp-plugin -i"
+                    if os.getuid() != 0:
+                        from base import password
+                        PasswordObj = password.Password(INTERACTIVE_MODE)
+                        PasswordObj.clearPassword()
+                        log.info("Enter Password to install the plugin")
+                        cmd = PasswordObj.getAuthCmd()%cmd
+
+                    # su -c '%s' --> su -c 'hp-plugin -i'
+                    if os_utils.execute(cmd) != 0:
+                        log.error("Failed to install Plugin.")
+                        clean_exit(1)
 
         ppds = cups.getSystemPPDs()
 
@@ -399,7 +424,7 @@ else: # INTERACTIVE_MODE
                     ', '.join(installed_print_devices[print_uri]))
 
                 ok, setup_print = tui.enter_yes_no("\nWould you like to install another print queue for this device", 'n')
-                if not ok: sys.exit(0)
+                if not ok: clean_exit(0)
 
         if setup_print:
             if auto:
@@ -426,7 +451,7 @@ else: # INTERACTIVE_MODE
 
                         if printer_name.lower().strip() == 'q':
                             log.info("OK, done.")
-                            sys.exit(0)
+                            clean_exit(0)
 
                         if not printer_name or printer_name.lower().strip() == 'm':
                             printer_name = printer_default_model
@@ -474,21 +499,20 @@ else: # INTERACTIVE_MODE
                 print_ppd, desc = print_ppd
                 log.info("\nFound PPD file: %s" % print_ppd)
 
-                if desc:
-                    log.info("Description: %s" % desc)
+                log.info("Description: %s" % desc)
 #
-                    if not auto:
-                        log.info("\nNote: The model number may vary slightly from the actual model number on the device.")
-                        ok, ans = tui.enter_yes_no("\nDoes this PPD file appear to be the correct one")
-                        if not ok: sys.exit(0)
-                        if not ans: enter_ppd = True
+                if not auto:
+                    log.info("\nNote: The model number may vary slightly from the actual model number on the device.")
+                    ok, ans = tui.enter_yes_no("\nDoes this PPD file appear to be the correct one")
+                    if not ok: clean_exit(0)
+                    if not ans: enter_ppd = True
 
 
             if enter_ppd:
                 enter_ppd = False
 
                 ok, enter_ppd = tui.enter_yes_no("\nWould you like to specify the path to the correct PPD file to use", 'n')
-                if not ok: sys.exit(0)
+                if not ok: clean_exit(0)
 
                 if enter_ppd:
                     ok = False
@@ -498,7 +522,7 @@ else: # INTERACTIVE_MODE
 
                         if user_input.lower().strip() == 'q':
                             log.info("OK, done.")
-                            sys.exit(0)
+                            clean_exit(0)
 
                         file_path = user_input
 
@@ -520,7 +544,7 @@ else: # INTERACTIVE_MODE
                                 log.error("No PPD 'NickName' found. This file may not be a valid PPD file.")
 
                             ok, ans = tui.enter_yes_no("\nUse this file")
-                            if not ok: sys.exit(0)
+                            if not ok: clean_exit(0)
                             if ans: print_ppd = file_path
 
                         else:
@@ -530,7 +554,7 @@ else: # INTERACTIVE_MODE
                             break
                 else:
                     log.error("PPD file required. Setup cannot continue. Exiting.")
-                    sys.exit(1)
+                    clean_exit(1)
 
             if auto:
                 location, info = '', 'Automatically setup by HPLIP'
@@ -540,7 +564,7 @@ else: # INTERACTIVE_MODE
 
                     if location.strip().lower() == 'q':
                         log.info("OK, done.")
-                        sys.exit(0)
+                        clean_exit(0)
 
                     # TODO: Validate chars
                     break
@@ -550,7 +574,7 @@ else: # INTERACTIVE_MODE
 
                     if info.strip().lower() == 'q':
                         log.info("OK, done.")
-                        sys.exit(0)
+                        clean_exit(0)
 
                     # TODO: Validate chars
                     break
@@ -567,27 +591,35 @@ else: # INTERACTIVE_MODE
             log.debug("Restart CUPS returned: exit=%d output=%s" % (status, output))
 
             time.sleep(1)
-            cups.setPasswordPrompt("You do not have permission to add a printer.")
             if not os.path.exists(print_ppd): # assume foomatic: or some such
-                status, status_str = cups.addPrinter(printer_name.encode('utf8'), print_uri,
-                    location, '', print_ppd, info)
+                add_prnt_args = (printer_name.encode('utf8'), print_uri, location, '', print_ppd, info)
             else:
-                status, status_str = cups.addPrinter(printer_name.encode('utf8'), print_uri,
-                    location, print_ppd, '', info)
+                add_prnt_args = (printer_name.encode('utf8'), print_uri, location, print_ppd, '', info)
+
+            status, status_str = cups.cups_operation(cups.addPrinter, INTERACTIVE_MODE, '', None, *add_prnt_args)
 
             log.debug("addPrinter() returned (%d, %s)" % (status, status_str))
+            log.debug(device.getSupportedCUPSDevices(['hp']))
 
-            installed_print_devices = device.getSupportedCUPSDevices(['hp'])
-
-            if print_uri not in installed_print_devices or \
-                printer_name not in installed_print_devices[print_uri]:
-
-                log.error("Printer queue setup failed. Please restart CUPS and try again.")
-                sys.exit(1)
+            if status != cups.IPP_OK:
+                log.error("Printer queue setup failed. Error : %s "%status_str)
+                clean_exit(1)
             else:
                 # sending Event to add this device in hp-systray
                 utils.sendEvent(EVENT_CUPS_QUEUES_CHANGED,print_uri, printer_name)
 
+        # Updating firmware download for supported devices.
+        if ignore_plugin_check is False and mq.get('fw-download', False):
+            try:
+                d = device.Device(print_uri)
+            except Error:
+                log.error("Error opening device. Firmware download is Failed.")
+            else:
+                if d.downloadFirmware():
+                    log.info("Firmware download successful.\n")
+                else:
+                    log.error("Firmware download is Failed.")
+                d.close()
 
         # ******************************* FAX QUEUE SETUP
         if setup_fax and not prop.fax_build:
@@ -612,7 +644,7 @@ else: # INTERACTIVE_MODE
             if not auto and fax_uri in installed_fax_devices:
                 log.warning("One or more fax queues already exist for this device: %s." % ', '.join(installed_fax_devices[fax_uri]))
                 ok, setup_fax = tui.enter_yes_no("\nWould you like to install another fax queue for this device", 'n')
-                if not ok: sys.exit(0)
+                if not ok: clean_exit(0)
 
         if setup_fax:
             if auto: # or fax_name is None:
@@ -639,7 +671,7 @@ else: # INTERACTIVE_MODE
 
                         if fax_name.lower().strip() == 'q':
                             log.info("OK, done.")
-                            sys.exit(0)
+                            clean_exit(0)
 
                         if not fax_name or fax_name.lower().strip() == 'm':
                             fax_name = fax_default_model
@@ -676,7 +708,7 @@ else: # INTERACTIVE_MODE
 
             if not fax_ppd:
                 log.error("Unable to find HP fax PPD file! Please check you HPLIP installation and try again.")
-                sys.exit(1)
+                clean_exit(1)
 
             if auto:
                 location, info = '', 'Automatically setup by HPLIP'
@@ -686,7 +718,7 @@ else: # INTERACTIVE_MODE
 
                     if location.strip().lower() == 'q':
                         log.info("OK, done.")
-                        sys.exit(0)
+                        clean_exit(0)
 
                     # TODO: Validate chars
                     break
@@ -696,7 +728,7 @@ else: # INTERACTIVE_MODE
 
                     if info.strip().lower() == 'q':
                         log.info("OK, done.")
-                        sys.exit(0)
+                        clean_exit(0)
 
                     # TODO: Validate chars
                     break
@@ -717,16 +749,11 @@ else: # INTERACTIVE_MODE
                     location, fax_ppd, '', info)
 
             log.debug("addPrinter() returned (%d, %s)" % (status, status_str))
+            log.debug(device.getSupportedCUPSDevices(['hpfax']))
 
-            installed_fax_devices = device.getSupportedCUPSDevices(['hpfax'])
-
-            log.debug(installed_fax_devices)
-
-            if fax_uri not in installed_fax_devices or \
-                fax_name not in installed_fax_devices[fax_uri]:
-
-                log.error("Fax queue setup failed. Please restart CUPS and try again.")
-                sys.exit(1)
+            if status != cups.IPP_OK:
+                log.error("Fax queue setup failed. Error : %s"%status_str)
+                clean_exit(1)
             else:
                 # sending Event to add this device in hp-systray
                 utils.sendEvent(EVENT_CUPS_QUEUES_CHANGED,fax_uri, fax_name)
@@ -744,7 +771,7 @@ else: # INTERACTIVE_MODE
 
                     if user_input == 'q':
                         log.info("OK, done.")
-                        sys.exit(0)
+                        clean_exit(0)
 
                     if not user_input:
                         user_input = 'y'
@@ -794,7 +821,7 @@ else: # INTERACTIVE_MODE
                                     phone_num = raw_input(log.bold("\nEnter the fax phone number for this device (q=quit) ?"))
                                 if phone_num.strip().lower() == 'q':
                                     log.info("OK, done.")
-                                    sys.exit(0)
+                                    clean_exit(0)
 
                                 if current_phone_num and (not phone_num or phone_num.strip().lower() == 'c'):
                                     phone_num = current_phone_num
@@ -822,7 +849,7 @@ else: # INTERACTIVE_MODE
                                     station_name = raw_input(log.bold("\nEnter the name and/or company for this device (q=quit) ?"))
                                 if station_name.strip().lower() == 'q':
                                     log.info("OK, done.")
-                                    sys.exit(0)
+                                    clean_exit(0)
 
                                 if current_station_name and (not station_name or station_name.strip().lower() == 'c'):
                                     station_name = current_station_name
@@ -855,7 +882,7 @@ else: # INTERACTIVE_MODE
                     print_test_page = True
             else:
                 ok, print_test_page = tui.enter_yes_no("\nWould you like to print a test page")
-                if not ok: sys.exit(0)
+                if not ok: clean_exit(0)
 
             if print_test_page:
                 path = utils.which('hp-testpage')
@@ -866,15 +893,16 @@ else: # INTERACTIVE_MODE
                     param = "-d%s" % print_uri
 
                 if len(path) > 0:
-                    cmd = 'hp-testpage %s' % param
+                    cmd = 'hp-testpage -i %s' % param
                 else:
-                    cmd = '/usr/local/bin/python2.7 ./testpage.py %s' % param
+                    cmd = '/usr/local/bin/python2.7 ./testpage.py -i %s' % param
 
                 os_utils.execute(cmd)
 
     except KeyboardInterrupt:
         log.error("User exit")
 
+cups.releaseCupsInstance()
 log.info("")
 log.info("Done.")
 
